@@ -360,9 +360,15 @@ def load(lib, IM_VERSION):
     lib.MagickFlopImage.restype = c_bool
     lib.MagickForwardFourierTransformImage.argtypes = [c_void_p, c_bool]
     lib.MagickForwardFourierTransformImage.restype = c_bool
-    lib.MagickFrameImage.argtypes = [
-        c_void_p, c_void_p, c_size_t, c_size_t, c_ssize_t, c_ssize_t
-    ]
+    if is_im_6:
+        lib.MagickFrameImage.argtypes = [
+            c_void_p, c_void_p, c_size_t, c_size_t, c_ssize_t, c_ssize_t
+        ]
+    else:
+        lib.MagickFrameImage.argtypes = [
+            c_void_p, c_void_p, c_size_t, c_size_t, c_ssize_t, c_ssize_t,
+            c_int
+        ]
     lib.MagickFrameImage.restype = c_bool
     lib.MagickFunctionImage.argtypes = [
         c_void_p, c_int, c_size_t, POINTER(c_double)
@@ -506,6 +512,11 @@ def load(lib, IM_VERSION):
         lib.MagickGetImageKurtosis.restype = c_bool
     lib.MagickGetImageLength.argtypes = [c_void_p, POINTER(c_size_t)]
     lib.MagickGetImageLength.restype = c_bool
+    if is_im_7:
+        lib.MagickGetImageMask.argtypes = [c_void_p, c_int]
+        lib.MagickGetImageMask.restype = c_void_p
+    else:
+        lib.MagickGetImageMask = None
     lib.MagickGetImageMatteColor.argtypes = [c_void_p, c_void_p]
     lib.MagickGetImageMatteColor.restype = c_bool
     if is_im_7:
@@ -633,6 +644,13 @@ def load(lib, IM_VERSION):
     else:
         lib.MagickLevelImageChannel = None
     if IM_VERSION >= 0x708:
+        try:
+            lib.MagickLevelImageColors.argtypes = [
+                c_void_p, c_void_p, c_void_p, c_bool
+            ]
+            lib.MagickLevelImageColors.restype = c_bool
+        except AttributeError:
+            lib.MagickLevelImageColors = None
         try:
             lib.MagickLevelizeImage.argtypes = [c_void_p, c_double, c_double,
                                                 c_double]
@@ -640,6 +658,7 @@ def load(lib, IM_VERSION):
         except AttributeError:
             lib.MagickLevelizeImage = None
     else:
+        lib.MagickLevelImageColors = None
         lib.MagickLevelizeImage = None
     lib.MagickLinearStretchImage.argtypes = [c_void_p, c_double, c_double]
     lib.MagickLinearStretchImage.restype = c_bool
@@ -647,6 +666,11 @@ def load(lib, IM_VERSION):
         c_void_p, c_size_t, c_size_t, c_double, c_double
     ]
     lib.MagickLiquidRescaleImage.restype = c_bool
+    try:
+        lib.MagickLocalContrastImage.argtypes = [c_void_p, c_double, c_double]
+        lib.MagickLocalContrastImage.restype = c_bool
+    except AttributeError:
+        lib.MagickLocalContrastImage = None
     lib.MagickMagnifyImage.argtypes = [c_void_p]
     lib.MagickMagnifyImage.restype = c_bool
     if IM_VERSION >= 0x708:
@@ -738,6 +762,9 @@ def load(lib, IM_VERSION):
         lib.MagickOptimizeImageTransparency.restype = c_bool
     except AttributeError:
         lib.MagickOptimizeImageTransparency = None
+    if is_im_7:
+        lib.MagickOrderedDitherImage.argtypes = [c_void_p, c_char_p]
+        lib.MagickOrderedDitherImage.restype = c_bool
     if is_im_6:
         lib.MagickOrderedPosterizeImage.argtypes = [c_void_p, c_char_p]
         lib.MagickOrderedPosterizeImage.restype = c_bool
@@ -951,6 +978,11 @@ def load(lib, IM_VERSION):
     lib.MagickSetImageInterpolateMethod.restype = c_bool
     lib.MagickSetImageIterations.argtypes = [c_void_p, c_size_t]
     lib.MagickSetImageIterations.restype = c_bool
+    if is_im_7:
+        lib.MagickSetImageMask.argtypes = [c_void_p, c_int, c_void_p]
+        lib.MagickSetImageMask.restype = c_bool
+    else:
+        lib.MagickSetImageMask = None
     lib.MagickSetImageMatte.argtypes = [c_void_p, c_bool]
     lib.MagickSetImageMatteColor.argtypes = [c_void_p, c_void_p]
     if is_im_6:
@@ -1089,8 +1121,12 @@ def load(lib, IM_VERSION):
     lib.MagickStereoImage.restype = c_void_p
     lib.MagickStripImage.argtypes = [c_void_p]
     lib.MagickStripImage.restype = c_bool
-    lib.MagickSwirlImage.argtypes = [c_void_p, c_double]
-    lib.MagickSwirlImage.restype = c_bool
+    if is_im_6:
+        lib.MagickSwirlImage.argtypes = [c_void_p, c_double]
+        lib.MagickSwirlImage.restype = c_bool
+    else:
+        lib.MagickSwirlImage.argtypes = [c_void_p, c_double, c_int]
+        lib.MagickSwirlImage.restype = c_bool
     lib.MagickTextureImage.argtypes = [c_void_p, c_void_p]
     lib.MagickTextureImage.restype = c_void_p
     lib.MagickTintImage.argtypes = [c_void_p, c_void_p, c_void_p]
